@@ -1,8 +1,8 @@
-
-require 5;
 package Pod::Simple::Progress;
-$VERSION = '3.37';
 use strict;
+use warnings;
+
+our $VERSION = '3.46';
 
 # Objects of this class are used for noting progress of an
 #  operation every so often.  Messages delivered more often than that
@@ -24,7 +24,7 @@ sub new {
   return $self;
 }
 
-sub copy { 
+sub copy {
   my $orig = shift;
   bless {%$orig, 'quiet_until' => 1}, ref($orig);
 }
