@@ -1,18 +1,17 @@
-require 5.005;
 package Pod::Simple::Search;
 use strict;
+use warnings;
 
-use vars qw($VERSION $MAX_VERSION_WITHIN $SLEEPY);
-$VERSION = '3.31';   ## Current version of this package
+our $VERSION = '3.46';   ## Current version of this package
 
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG; }   # set DEBUG level
 use Carp ();
 
+our $SLEEPY;
 $SLEEPY = 1 if !defined $SLEEPY and $^O =~ /mswin|mac/i;
   # flag to occasionally sleep for $SLEEPY - 1 seconds.
 
-$MAX_VERSION_WITHIN ||= 60;
-my $IS_CASE_INSENSITIVE = -e uc __FILE__ && -e lc __FILE__;
+our $MAX_VERSION_WITHIN ||= 60;
 
 #############################################################################
 
@@ -26,7 +25,7 @@ use Cwd qw( cwd );
 __PACKAGE__->_accessorize(  # Make my dumb accessor methods
  'callback', 'progress', 'dir_prefix', 'inc', 'laborious', 'limit_glob',
  'limit_re', 'shadows', 'verbose', 'name2path', 'path2name', 'recurse',
- 'ciseen'
+ 'ciseen', 'is_case_insensitive'
 );
 #==========================================================================
 
@@ -42,6 +41,7 @@ sub init {
   $self->inc(1);
   $self->recurse(1);
   $self->verbose(DEBUG);
+  $self->is_case_insensitive(-e uc __FILE__ && -e lc __FILE__);
   return $self;
 }
 
@@ -91,26 +91,26 @@ sub survey {
     } else {
       $self->{'_dirs_visited'}{$start_in} = 1;
     }
-  
+
     unless(-e $start_in) {
       $verbose and print "Skipping non-existent $start_in\n";
       next;
     }
 
     my $closure = $self->_make_search_callback;
-    
+
     if(-d $start_in) {
       # Normal case:
       $verbose and print "Beginning excursion under $start_in\n";
       $self->_recurse_dir( $start_in, $closure, $modname_prefix );
       $verbose and print "Back from excursion under $start_in\n\n";
-        
+
     } elsif(-f _) {
       # A excursion consisting of just one file!
       $_ = basename($start_in);
       $verbose and print "Pondering $start_in ($_)\n";
       $closure->($start_in, $_, 0, []);
-        
+
     } else {
       $verbose and print "Skipping mysterious $start_in\n";
     }
@@ -130,12 +130,12 @@ sub _make_search_callback {
 
   # Put the options in variables, for easy access
   my( $laborious, $verbose, $shadows, $limit_re, $callback, $progress,
-      $path2name, $name2path, $recurse, $ciseen) =
+      $path2name, $name2path, $recurse, $ciseen, $is_case_insensitive) =
     map scalar($self->$_()),
      qw(laborious verbose shadows limit_re callback progress
-        path2name name2path recurse ciseen);
+        path2name name2path recurse ciseen is_case_insensitive);
   my ($seen, $remember, $files_for);
-  if ($IS_CASE_INSENSITIVE) {
+  if ($is_case_insensitive) {
       $seen      = sub { $ciseen->{ lc $_[0] } };
       $remember  = sub { $name2path->{ $_[0] } = $ciseen->{ lc $_[0] } = $_[1]; };
       $files_for = sub { my $n = lc $_[0]; grep { lc $path2name->{$_} eq $n } %{ $path2name } };
@@ -202,7 +202,7 @@ sub _make_search_callback {
     $verbose and print "Considering item $file\n";
     my $name = $self->_path2modname( $file, $shortname, $modname_bits );
     $verbose > 0.01 and print " Nominating $file as $name\n";
-        
+
     if($limit_re and $name !~ m/$limit_re/i) {
       $verbose and print "Shunning $name as not matching $limit_re\n";
       return;
@@ -259,7 +259,7 @@ sub _path2modname {
   while(@m
     and defined($x = lc( $m[0] ))
     and(  $x eq 'site_perl'
-       or($x eq 'pod' and @m == 1 and $shortname =~ m{^perl.*\.pod$}s )
+       or($x =~ m/^pods?$/ and @m == 1 and $shortname =~ m{^perl.*\.pod$}s )
        or $x =~ m{\\d+\\.z\\d+([_.]?\\d+)?}  # if looks like a vernum
        or $x eq lc( $Config::Config{'archname'} )
   )) { shift @m }
@@ -351,7 +351,7 @@ sub _recurse_dir {
 
       if(!-r $i_full) {
         $verbose and print "Skipping unreadable $i_full\n";
-       
+
       } elsif(-f $i_full) {
         $_ = $i;
         $callback->(          $i_full, $i, 0, $modname_bits );
@@ -380,7 +380,7 @@ sub _recurse_dir {
 
   undef $recursor;  # allow it to be GC'd
 
-  return;  
+  return;
 }
 
 
@@ -394,11 +394,11 @@ sub run {
   $self->callback( sub {
     my($file, $name) = @_;
     my $version = '';
-     
+
     # Yes, I know we won't catch the version in like a File/Thing.pm
     #  if we see File/Thing.pod first.  That's just the way the
     #  cookie crumbles.  -- SMB
-     
+
     if($file =~ m/\.pod$/i) {
       # Don't bother looking for $VERSION in .pod files
       DEBUG and print "Not looking for \$VERSION in .pod $file\n";
@@ -423,12 +423,12 @@ sub run {
              or m{\$Revision:\s*([0-9_]+(?:\.[0-9_]+)*)\s*\$}s
              # like in sprintf("%d.%02d", q$Revision: 4.13 $ =~ /(\d+)\.(\d+)/);
           ;
-           
+
           # Like in sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_55-public $ =~ /-(\d+)_([\d_]+)/)
           $_ = sprintf("v%d.%s",
             map {s/_//g; $_}
               $1 =~ m/-(\d+)_([\d_]+)/) # snare just the numeric part
-           if m{\$Name:\s*([^\$]+)\$}s 
+           if m{\$Name:\s*([^\$]+)\$}s
           ;
           $version = $_;
           DEBUG and print "Noting $version as version\n";
@@ -449,13 +449,13 @@ sub run {
 
 sub simplify_name {
   my($self, $str) = @_;
-    
+
   # Remove all path components
   #                             XXX Why not just use basename()? -- SMB
 
   if ($^O eq 'MacOS') { $str =~ s{^.*:+}{}s }
   else                { $str =~ s{^.*/+}{}s }
-  
+
   $self->_simplify_base($str);
   return $str;
 }
@@ -480,7 +480,7 @@ sub _simplify_base {   # Internal method only
 
 sub _expand_inc {
   my($self, $search_dirs) = @_;
-  
+
   return unless $self->{'inc'};
   my %seen = map { File::Spec->rel2abs($_) => 1 } @{ $search_dirs };
 
@@ -546,7 +546,7 @@ sub _limit_glob_to_limit_re {
 sub _actual_filenames {
     my $dir = shift;
     my $fn = lc shift;
-    opendir my $dh, $dir or return;
+    opendir my ($dh), $dir or return;
     return map { File::Spec->catdir($dir, $_) }
         grep { lc $_  eq $fn } readdir $dh;
 }
@@ -566,7 +566,7 @@ sub find {
   $verbose and print "Chomping {$pod} => {@parts}\n";
 
   #@search_dirs = File::Spec->curdir unless @search_dirs;
-  
+
   $self->_expand_inc(\@search_dirs);
   # Add location of binaries such as pod2text:
   push @search_dirs, $Config::Config{'scriptdir'} if $self->inc;
@@ -588,7 +588,7 @@ sub find {
       my $fullext = $fullname . $ext;
       if ( -f $fullext and $self->contains_pod($fullext) ) {
         print "FOUND: $fullext\n" if $verbose;
-        if (@parts > 1 && lc $parts[0] eq 'pod' && $IS_CASE_INSENSITIVE && $ext eq '.pod') {
+        if (@parts > 1 && lc $parts[0] eq 'pod' && $self->is_case_insensitive() && $ext eq '.pod') {
           # Well, this file could be for a program (perldoc) but we actually
           # want a module (Pod::Perldoc). So see if there is a .pm with the
           # proper casing.
@@ -611,7 +611,7 @@ sub find {
     }
 
     # Case-insensitively Look for ./pod directories and slip them in.
-    for my $subdir ( _actual_filenames($dir, 'pod') ) {
+    for my $subdir ( _actual_filenames($dir, 'pods'), _actual_filenames($dir, 'pod') ) {
       if (-d $subdir) {
         $verbose and print "Noticing $subdir and looking there...\n";
         unshift @search_dirs, $subdir;
@@ -637,7 +637,7 @@ sub contains_pod {
 
   sleep($SLEEPY - 1) if $SLEEPY;
    # avoid totally hogging the processor on OSs with poor process control
-  
+
   local $_;
   while( <MAYBEPOD> ) {
     if(m/^=(head\d|pod|over|item)\b/s) {
@@ -820,7 +820,7 @@ is called.
 
 =item $search->laborious( I<true-or-false> );
 
-Unless you set this attribute to a true value, Pod::Search will 
+Unless you set this attribute to a true value, Pod::Search will
 apply Perl-specific heuristics to find the correct module PODs quickly.
 This attribute's default value is false.  You won't normally need
 to set this to true.
@@ -849,6 +849,20 @@ inspected too, and are noted in the pathname2podname return hash.
 This attribute's default value is false; and normally you won't
 need to turn it on.
 
+=item $search->is_case_insensitive( I<true-or-false> );
+
+Pod::Simple::Search will by default internally make an assumption
+based on the underlying filesystem where the class file is found
+whether it is case insensitive or not.
+
+If it is determined to be case insensitive, during survey() it may
+skip pod files/modules that happen to be equal to names it's already
+seen, ignoring case.
+
+However, it's possible to have distinct files in different directories
+that intentionally has the same name, just differing in case, that should
+be reported. Hence, you may force the behavior by setting this to true
+or false.
 
 =item $search->limit_re( I<some-regxp> );
 
@@ -857,7 +871,6 @@ to limit the results just to items whose podnames match the given
 regexp. Normally this option is not needed, and the more efficient
 C<limit_glob> attribute is used instead.
 
-
 =item $search->dir_prefix( I<some-string-value> );
 
 Setting this attribute to a string value means that the searches should
@@ -877,7 +890,7 @@ and usually dir_prefix.)
 =item $search->progress( I<some-progress-object> );
 
 If you set a value for this attribute, the value is expected
-to be an object (probably of a class that you define) that has a 
+to be an object (probably of a class that you define) that has a
 C<reach> method and a C<done> method.  This is meant for reporting
 progress during the search, if you don't want to use a simple
 callback.
@@ -1017,7 +1030,7 @@ The C<verbose> and C<inc> attributes influence the behavior of this
 search; notably, C<inc>, if true, adds @INC I<and also
 $Config::Config{'scriptdir'}> to the list of directories to search.
 
-It is common to simply say C<< $filename = Pod::Simple::Search-> new 
+It is common to simply say C<< $filename = Pod::Simple::Search-> new
 ->find("perlvar") >> so that just the @INC (well, and scriptdir)
 directories are searched.  (This happens because the C<inc>
 attribute is true by default.)
@@ -1040,7 +1053,7 @@ pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
 L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+to clone L<https://github.com/perl-pod/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
